==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGridSelectionRangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDetailDescription } from "./WebGridSelectionRangeDetailDescription";
/**
 * @hidden
 */
var WebGridSelectionRangeDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridSelectionRangeDetailDescriptionMetadata, _super);
    function WebGridSelectionRangeDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridSelectionRangeDetailDescriptionMetadata.b = function (a) {
        if (WebGridSelectionRangeDetailDescriptionMetadata.a == null) {
            WebGridSelectionRangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridSelectionRangeDetailDescriptionMetadata.c(WebGridSelectionRangeDetailDescriptionMetadata.a);
        }
        if (a.k(WebGridSelectionRangeDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGridSelectionRangeDetailDescriptionMetadata.a);
    };
    WebGridSelectionRangeDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridSelectionRangeDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("RowStart", "Number:double");
        a.item("RowEnd", "Number:double");
        a.item("ColumnStart", "String");
        a.item("ColumnEnd", "String");
    };
    WebGridSelectionRangeDetailDescriptionMetadata.d = function (a) {
        WebGridSelectionRangeDetailDescriptionMetadata.b(a);
        a.ad("WebGridSelectionRangeDetail", function () { return new WebGridSelectionRangeDetailDescription(); });
        a.ac("WebGridSelectionRangeDetail", WebGridSelectionRangeDetailDescriptionMetadata.a);
    };
    WebGridSelectionRangeDetailDescriptionMetadata.$t = markType(WebGridSelectionRangeDetailDescriptionMetadata, 'WebGridSelectionRangeDetailDescriptionMetadata');
    WebGridSelectionRangeDetailDescriptionMetadata.a = null;
    return WebGridSelectionRangeDetailDescriptionMetadata;
}(Base));
export { WebGridSelectionRangeDetailDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebGridSelectionRangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDetailDescription } from "./WebGridSelectionRangeDetailDescription";
/**
 * @hidden
 */
var WebGridSelectionRangeDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridSelectionRangeDetailDescriptionMetadata, _super);
    function WebGridSelectionRangeDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridSelectionRangeDetailDescriptionMetadata.b = function (a) {
        if (WebGridSelectionRangeDetailDescriptionMetadata.a == null) {
            WebGridSelectionRangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridSelectionRangeDetailDescriptionMetadata.c(WebGridSelectionRangeDetailDescriptionMetadata.a);
        }
        if (a.k(WebGridSelectionRangeDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGridSelectionRangeDetailDescriptionMetadata.a);
    };
    WebGridSelectionRangeDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridSelectionRangeDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("__isTSPlainInterface", "Boolean");
        a.item("RowStart", "Number:double");
        a.item("RowEnd", "Number:double");
        a.item("ColumnStart", "Number:double");
        a.item("ColumnEnd", "Number:double");
    };
    WebGridSelectionRangeDetailDescriptionMetadata.d = function (a) {
        WebGridSelectionRangeDetailDescriptionMetadata.b(a);
        a.ae("WebGridSelectionRangeDetail", function () { return new WebGridSelectionRangeDetailDescription(); });
        a.ad("WebGridSelectionRangeDetail", WebGridSelectionRangeDetailDescriptionMetadata.a);
    };
    WebGridSelectionRangeDetailDescriptionMetadata.$t = markType(WebGridSelectionRangeDetailDescriptionMetadata, 'WebGridSelectionRangeDetailDescriptionMetadata');
    WebGridSelectionRangeDetailDescriptionMetadata.a = null;
    return WebGridSelectionRangeDetailDescriptionMetadata;
}(Base));
export { WebGridSelectionRangeDetailDescriptionMetadata };
